@@ -8,7 +8,8 @@ def objectset_form_factory(Model, queryset=None):
     In addition, an optional queryset can be supplied to limit the choices
     for the objects.
 
-    This uses the generic `objects` field rathr
+    This uses the generic `objects` field rather being named after a specific
+    type.
     """
     # A few checks to keep things sane..
     if not issubclass(Model, ObjectSet):
@@ -19,15 +20,24 @@ def objectset_form_factory(Model, queryset=None):
     if queryset is None:
         queryset = instance._object_class._default_manager.all()
     elif queryset.model is not instance._object_class:
-        raise TypeError('ObjectSet of type {0}, not {1}'.format(instance._object_class.__name__, queryset.model.__name__))
+        raise TypeError('ObjectSet of type {0}, not {1}'
+                        .format(instance._object_class.__name__,
+                                queryset.model.__name__))
 
     label = getattr(Model, instance._set_object_rel).field.verbose_name
 
     class form_class(forms.ModelForm):
-        objects = forms.ModelMultipleChoiceField(queryset, label=label, required=False)
+        objects = forms.ModelMultipleChoiceField(queryset, label=label,
+                                                 required=False)
 
         def save(self, *args, **kwargs):
-            self.instance._pending = self.cleaned_data.get('objects')
+            objects = self.cleaned_data.get('objects')
+            # Django 1.4 nuance when working with an empty list. It is not
+            # properly defined an empty query set
+            if isinstance(objects, list) and not objects:
+                objects = self.instance.__class__.objects.none()
+
+            self.instance._pending = objects
             return super(form_class, self).save(*args, **kwargs)
 
         class Meta(object):
